## PAD RTEMS startup script for klystron 21-1 PAD_KLY app

# Set some abbreviations
ld    = cexpModuleLoad
unld  = cexpModuleUnload

ld("bin/pad.obj") 

# nfsMount the filesystem for output data
#This configuration works while the PAD is on IFZ 134.79.21[6-9] subnet
# nfsMount("[uid.gid@]hostip", "path on host", "local mountpoint")
#nfsMount("6871.1086@134.79.219.11","/home/dayle/padData","/data")
nfsMount("134.79.59.74","/export","/mntPt")

## Set common environment variables. eg. EPICS_TS_NTP_INET and PORTs
cexpsh("../../../config/epicsEnvSetDev")
# PAD needs to be able to see VME
#epicsEnvSet("EPICS_CA_ADDR_LIST","134.79.219.32")
#epicsEnvSet("EPICS_CA_AUTO_ADDR_LIST","NO")

## Set app-specific environment variable for the PAD
epicsEnvSet ("EPICS_CA_MAX_ARRAY_BYTES", "600000")
#ALT: setenv("EPICS_CA_MAX_ARRAY_BYTES","20000000",1)

## Register all support components
dbLoadDatabase("dbd/pad.dbd")
pad_registerRecordDeviceDriver(pdbbase) 

## Load record instances
dbLoadTemplate("db/padK211.template")

devLongoutPadFlag=1
devLonginPadFlag=1
devWaveformPadFlag=1
devMbboPadFlag=1
devBoPadFlag=4
drvPadFlag=1

iocInit()

devBoPadFlag=1

# force scalar waveforms to read (once)
dbpf("PAD:K211:1:CH0_SCALAR_WF.PROC","1")
dbpf("PAD:K211:1:CH1_SCALAR_WF.PROC","1")
dbpf("PAD:K211:1:CH2_SCALAR_WF.PROC","1")
dbpf("PAD:K211:1:CH3_SCALAR_WF.PROC","1")

# if testing by hand, stop some stuff from processing
#dbpf("PAD:K211:1:CH0.SCAN", "Passive")
#dbpf("PAD:K211:1:CH1.SCAN", "Passive")
#dbpf("PAD:K211:1:CH2.SCAN", "Passive")
#dbpf("PAD:K211:1:CH3.SCAN", "Passive")
#dbpf("PAD:K211:1:CH4.SCAN", "Passive")
#dbpf("PAD:K211:1:CH5.SCAN", "Passive")
#dbpf("PAD:K211:1:CH6.SCAN", "Passive")
#dbpf("PAD:K211:1:CH7.SCAN", "Passive")

drvPadCfgFlag=1
drvPadScalFlag=1
drvPadIntrFlag=1

#override what's set for the offset to the start of the data here
#padSetSampleOffset(channel, sample, n) usage: sample is the sample number (0 for most, can be 1 if BPH)
#                                     n is the number of 16 bit words to read 
#                                     after first 3 clock cycless. 
dbpf("PAD:K211:1:CH0_OFST","0")
dbpf("PAD:K211:1:CH1_OFST","0")
dbpf("PAD:K211:1:CH2_OFST","0")
dbpf("PAD:K211:1:CH3_OFST","300")
dbpf("PAD:K211:1:CH4_OFST","0")

#override what's set for the size of the data here
#padSetSampleSize(channel, sample, n) usage: sample is the sample number (0 for most, can be 1 if BPH)
#                                   n must be a multiple of 4 since 
#                                   data in quadruples of (Q1,I2,Q3,I4) read 
#                                   (see comments in drvPad.c for more info)
dbpf("PAD:K211:1:CH0_SIZE","1024")
dbpf("PAD:K211:1:CH1_SIZE","1024")
dbpf("PAD:K211:1:CH2_SIZE","1024")
dbpf("PAD:K211:1:CH3_SIZE","100")
dbpf("PAD:K211:1:CH4_SIZE","65536")

padSetDataFileStem("dayle") 	# The stem to start all data files with
                                # Format is "<stem><secPastEpoch>.dat"

# change directory to local mountpoint so that files don't need path to dir in their name
#cd("/data") for lcls-dev
cd("/mntPt") # for klyron

#rtems_gdb_start(0,0)

## Start any sequence programs. Note: RTEMS Cexp syntax
seq(&sncpad,"PRIM=PAD,LOCA=K211,UNIT=1")

