## PAD RTEMS startup script for RF Gun Forward/Reflected PAD in RF Hut

chdir("/boot/lcls/epics/iocTop/LLRF/Pad-Prod")
ld("bin/RTEMS-uC5282/pad-gen.obj")  

## Set common environment variables
< /boot/lcls/epics/iocCommon/All/Prod/pre_st.cmd

## /data now mapped by pre...
nfsMountsShow()

## Set app-specific environment variable for the PAD
epicsEnvSet ("EPICS_CA_MAX_ARRAY_BYTES", "600000")
#ALT: setenv("EPICS_CA_MAX_ARRAY_BYTES","20000000",1)

## Register all support components
dbLoadDatabase("dbd/pad.dbd")
pad_registerRecordDeviceDriver(pdbbase) 

## Load record instances
dbLoadTemplate("db/padGN2.gen102_template")
dbLoadRecords("db/iocAdmin.db","IOC=EIOC:IN20:RD04")

## Set to 2 so that we see errors
devLongoutPadFlag=2
devLonginPadFlag=2
devWaveformPadFlag=2
devMbboPadFlag=2
devBoPadFlag=2
drvPadFlag=2
drvPadCfgFlag=2
drvPadScalFlag=2
drvPadIntrFlag=2

## For this app, channels 2 and 3 aren't used, so numQ is zero,
## so set drvPadGenFlag=0 to avoid all the msgs that "numQ is zero"
drvPadGenFlag=0

# New: pre maps /data to /u1/lcls/epics/ioc/data/<hostname>
dbRestore("/data/EIOC-IN20-RD04.sav")

iocInit()

# lower flags from 4 to 2 if too verbose for processing

# force scalar waveforms to read (once)
dbpf("GUN:IN20:1:GN2_0_SCL_WF.PROC","1")
dbpf("GUN:IN20:1:GN2_1_SCL_WF.PROC","1")
dbpf("GUN:IN20:1:GN2_2_SCL_WF.PROC","1")
dbpf("GUN:IN20:1:GN2_3_SCL_WF.PROC","1")

# if testing by hand, stop some stuff from processing
#dbpf("GUN:IN20:1:GN2_0.SCAN", "Passive")
#dbpf("GUN:IN20:1:GN2_1.SCAN", "Passive")
#dbpf("GUN:IN20:1:GN2_2.SCAN", "Passive")
#dbpf("GUN:IN20:1:GN2_3.SCAN", "Passive")
#dbpf("GUN:IN20:1:GN2_4.SCAN", "Passive")
#dbpf("GUN:IN20:1:GN2_5.SCAN", "Passive")
#dbpf("GUN:IN20:1:GN2_6.SCAN", "Passive")
#dbpf("GUN:IN20:1:GN2_7.SCAN", "Passive")

#override what's set for the offset to the start of the data here
#padSetSampleOffset(channel, sample, n) usage: sample is the sample number (0 for most, can be 1 if BPH)
#                                     n is the number of 16 bit words to read 
#                                     after first 3 clock cycless. 
dbpf("GUN:IN20:1:GN2_4_OFST","0")
dbpf("GUN:IN20:1:GN2_5_OFST","0")
dbpf("GUN:IN20:1:GN2_6_OFST","0")
dbpf("GUN:IN20:1:GN2_7_OFST","0")

#override what's set for the size of the data here
#padSetSampleSize(channel, sample, n) usage: sample is the sample number (0 for most, can be 1 if BPH)
#                                   n must be a multiple of 4 since 
#                                   data in quadruples of (Q1,I2,Q3,I4) read 
#                                   (see comments in drvPad.c for more info)
dbpf("GUN:IN20:1:GN2_4_SIZE","65536")
dbpf("GUN:IN20:1:GN2_5_SIZE","65536")
dbpf("GUN:IN20:1:GN2_6_SIZE","65536")
dbpf("GUN:IN20:1:GN2_7_SIZE","65536")

padSetDataFileStem("dayle") 	# The stem to start all data files with
                                # Format is "<stem><secPastEpoch>.dat"

# change directory to local mountpoint so that files don't need path to dir in their name
cd("/data") # for lcls-dev
#cd("/mntPt") # for klyron

#rtems_gdb_start(0,0)

dbpf("GUN:IN20:1:GN2_0_OFST.PROC","1")
dbpf("GUN:IN20:1:GN2_1_OFST.PROC","1")
dbpf("GUN:IN20:1:GN2_2_OFST.PROC","1")
dbpf("GUN:IN20:1:GN2_3_OFST.PROC","1")
dbpf("GUN:IN20:1:GN2_0_SIZE.PROC","1")
dbpf("GUN:IN20:1:GN2_1_SIZE.PROC","1")
dbpf("GUN:IN20:1:GN2_2_SIZE.PROC","1")
dbpf("GUN:IN20:1:GN2_3_SIZE.PROC","1")

## Start any sequence programs. Note: RTEMS Cexp syntax
# Skip state machine for nonlin test
seq(&sncpad,"PRIM=GUN,LOCA=IN20,UNIT=1,PAD=GN2") 

# for non-lin test
#padSetOperationMode(1)
#dbpf("GUN:IN20:1:GN2_D_CALIB","1")
#padDisableIntr()
#padNonlin(1000)

