## PAD RTEMS startup script for L0 PAD in RF Hut PAD_GEN app

chdir("/boot/lcls/epics/iocTop/LLRF/Pad-Prod")
ld("bin/RTEMS-uC5282/pad-gen.obj") 

## Set common environment variables
< /boot/lcls/epics/iocCommon/All/Prod/pre_st.cmd

## /data now mapped by pre...
nfsMountsShow()

## Set app-specific environment variable for the PAD
epicsEnvSet ("EPICS_CA_MAX_ARRAY_BYTES", "600000")
#ALT: setenv("EPICS_CA_MAX_ARRAY_BYTES","20000000",1)

## Register all support components
dbLoadDatabase("dbd/pad.dbd")
pad_registerRecordDeviceDriver(pdbbase) 

## Load record instances
dbLoadTemplate("db/padL0.gen102_template")
dbLoadRecords("db/iocAdmin.db","IOC=EIOC:IN20:RD06")

## Set to 2 so that we see errors
devLongoutPadFlag=2
devLonginPadFlag=2
devWaveformPadFlag=2
devMbboPadFlag=2
devBoPadFlag=2
drvPadFlag=2
drvPadCfgFlag=2
drvPadScalFlag=2
drvPadIntrFlag=2

# New: pre maps /data to /u1/lcls/epics/ioc/data/<hostname>
dbRestore("/data/EIOC-IN20-RD06.sav")

iocInit()

# lower flags from 4 to 2 if too verbose for processing

# force scalar waveforms to read (once)
dbpf("ACCL:IN20:350:L0_0_SCL_WF.PROC","1")
dbpf("ACCL:IN20:350:L0_1_SCL_WF.PROC","1")
dbpf("ACCL:IN20:350:L0_2_SCL_WF.PROC","1")
dbpf("ACCL:IN20:350:L0_3_SCL_WF.PROC","1")

# if testing by hand, stop some stuff from processing
#dbpf("ACCL:IN20:350:L0_0.SCAN", "Passive")
#dbpf("ACCL:IN20:350:L0_1.SCAN", "Passive")
#dbpf("ACCL:IN20:350:L0_2.SCAN", "Passive")
#dbpf("ACCL:IN20:350:L0_3.SCAN", "Passive")
#dbpf("ACCL:IN20:350:L0_4.SCAN", "Passive")
#dbpf("ACCL:IN20:350:L0_5.SCAN", "Passive")
#dbpf("ACCL:IN20:350:L0_6.SCAN", "Passive")
#dbpf("ACCL:IN20:350:L0_7.SCAN", "Passive")

#override what's set for the offset to the start of the data here
#padSetSampleOffset(channel, sample, n) usage: sample is the sample number (0 for most, can be 1 if BPH)
#                                     n is the number of 16 bit words to read 
#                                     after first 3 clock cycless. 
dbpf("ACCL:IN20:350:L0_4_OFST","0")
dbpf("ACCL:IN20:350:L0_5_OFST","0")
dbpf("ACCL:IN20:350:L0_6_OFST","0")
dbpf("ACCL:IN20:350:L0_7_OFST","0")

#override what's set for the size of the data here
#padSetSampleSize(channel, sample, n) usage: sample is the sample number (0 for most, can be 1 if BPH)
#                                   n must be a multiple of 4 since 
#                                   data in quadruples of (Q1,I2,Q3,I4) read 
#                                   (see comments in drvPad.c for more info)
dbpf("ACCL:IN20:350:L0_4_SIZE","65536")
dbpf("ACCL:IN20:350:L0_5_SIZE","65536")
dbpf("ACCL:IN20:350:L0_6_SIZE","65536")
dbpf("ACCL:IN20:350:L0_7_SIZE","65536")

padSetDataFileStem("dayle") 	# The stem to start all data files with
                                # Format is "<stem><secPastEpoch>.dat"

# change directory to local mountpoint so that files don't need path to dir in their name
cd("/data") # for lcls-dev

rtems_gdb_start(0,0)

dbpf("ACCL:IN20:350:L0_0_OFST.PROC","1")
dbpf("ACCL:IN20:350:L0_1_OFST.PROC","1")
dbpf("ACCL:IN20:350:L0_2_OFST.PROC","1")
dbpf("ACCL:IN20:350:L0_3_OFST.PROC","1")
dbpf("ACCL:IN20:350:L0_0_SIZE.PROC","1")
dbpf("ACCL:IN20:350:L0_1_SIZE.PROC","1")
dbpf("ACCL:IN20:350:L0_2_SIZE.PROC","1")
dbpf("ACCL:IN20:350:L0_3_SIZE.PROC","1")

## Start any sequence programs. Note: RTEMS Cexp syntax
# Skip state machine for nonlin test
seq(&sncpad,"PRIM=ACCL,LOCA=IN20,UNIT=350,PAD=L0") 

# for non-lin test
#padSetOperationMode(1)
#dbpf("ACCL:IN20:350:L0_D_CALIB","1")
#padDisableIntr()
#padNonlin(1000)

