## PAD RTEMS startup script for Laser PAD in RF Hut PAD_LSR app

chdir("/boot/lcls/epics/iocTop/LLRF/Pad-Prod")
ld("bin/RTEMS-uC5282/pad-lsr.obj") 

## Set common environment variables
< /boot/lcls/epics/iocCommon/All/Prod/pre_st.cmd

## /data now mapped by pre...
nfsMountsShow()

## Set app-specific environment variable for the PAD
epicsEnvSet ("EPICS_CA_MAX_ARRAY_BYTES", "600000")
#ALT: setenv("EPICS_CA_MAX_ARRAY_BYTES","20000000",1)

## Register all support components
dbLoadDatabase("dbd/pad.dbd")
pad_registerRecordDeviceDriver(pdbbase) 

## Load record instances
dbLoadTemplate("db/padLSR.lsr_template")
dbLoadRecords("db/iocAdmin.db","IOC=EIOC:IN20:RD02")

## Set to 2 so that we see errors
devLongoutPadFlag=2
devLonginPadFlag=2
devWaveformPadFlag=2
devMbboPadFlag=2
devBoPadFlag=2
drvPadFlag=2
drvPadCfgFlag=2
drvPadScalFlag=2
drvPadIntrFlag=2

# New: pre maps /data to /u1/lcls/epics/ioc/data/<hostname>
dbRestore("/data/EIOC-IN20-RD02.sav")

iocInit()

drvPadScalFlag=2

# force scalar waveforms to read (once)
dbpf("LASR:IN20:1:LSR_0_SCL_WF.PROC","1")
dbpf("LASR:IN20:1:LSR_1_SCL_WF.PROC","1")
dbpf("LASR:IN20:1:LSR_2_SLI_WF.PROC","1")
dbpf("LASR:IN20:1:LSR_2_SLQ_WF.PROC","1")
dbpf("LASR:IN20:1:LSR_3_SLI_WF.PROC","1")
dbpf("LASR:IN20:1:LSR_3_SLQ_WF.PROC","1")


# if testing by hand, stop some stuff from processing
#dbpf("LASR:IN20:1:LSR_0.SCAN", "Passive")
#dbpf("LASR:IN20:1:LSR_1.SCAN", "Passive")
#dbpf("LASR:IN20:1:LSR_2.SCAN", "Passive")
#dbpf("LASR:IN20:1:LSR_3.SCAN", "Passive")
#dbpf("LASR:IN20:1:LSR_4.SCAN", "Passive")
#dbpf("LASR:IN20:1:LSR_5.SCAN", "Passive")
#dbpf("LASR:IN20:1:LSR_6.SCAN", "Passive")
#dbpf("LASR:IN20:1:LSR_7.SCAN", "Passive")

#override what's set for the offset to the start of the data here
#padSetSampleOffset(channel, sample, n) usage: sample is the sample number (0 for most, can be 1 if BPH)
#                                     n is the number of 16 bit words to read 
#                                     after first 3 clock cycless. 
dbpf("LASR:IN20:1:LSR_4_OFST","0")
dbpf("LASR:IN20:1:LSR_5_OFST","0")
dbpf("LASR:IN20:1:LSR_6_OFST","0")
dbpf("LASR:IN20:1:LSR_7_OFST","0")

#override what's set for the size of the data here
#padSetSampleSize(channel, sample, n) usage: sample is the sample number (0 for most, can be 1 if BPH)
#                                   n must be a multiple of 4 since 
#                                   data in quadruples of (Q1,I2,Q3,I4) read 
#                                   (see comments in drvPad.c for more info)
dbpf("LASR:IN20:1:LSR_4_SIZE","65536")
dbpf("LASR:IN20:1:LSR_5_SIZE","65536")
dbpf("LASR:IN20:1:LSR_6_SIZE","65536")
dbpf("LASR:IN20:1:LSR_7_SIZE","65536")

padSetDataFileStem("dayle") 	# The stem to start all data files with
                                # Format is "<stem><secPastEpoch>.dat"

# change directory to local mountpoint so that files don't need path to dir in their name
cd("/data") # for lcls-dev

#rtems_gdb_start(0,0)

# Adding PINI=YES for these would obviate next 8 lines
dbpf("LASR:IN20:1:LSR_0_OFST.PROC","1")  
dbpf("LASR:IN20:1:LSR_1_OFST.PROC","1")
dbpf("LASR:IN20:1:LSR_2_OFST.PROC","1")
dbpf("LASR:IN20:1:LSR_3_OFST.PROC","1")
dbpf("LASR:IN20:1:LSR_0_SIZE.PROC","1")  
dbpf("LASR:IN20:1:LSR_1_SIZE.PROC","1")
dbpf("LASR:IN20:1:LSR_2_SIZE.PROC","1")
dbpf("LASR:IN20:1:LSR_3_SIZE.PROC","1")

## Start any sequence programs. Note: RTEMS Cexp syntax
# Skip state machine for nonlin test
seq(&sncpad,"PRIM=LASR,LOCA=IN20,UNIT=1,PAD=LSR") 

# for non-lin test
#padSetOperationMode(1)
#dbpf("PAD:IN20:1:LSR_D_CALIB","1")
#padDisableIntr()
#padNonlin(1000)

