## PAD RTEMS startup script for Phase Cavity 1 PAD_BPH app

chdir("/boot/lcls/epics/iocTop/LLRF/Pad-Prod")
ld("bin/RTEMS-uC5282/pad-bph.obj") 

## Set common environment variables
< /boot/lcls/epics/iocCommon/All/Prod/pre_st.cmd

## /data now mapped by pre...
nfsMountsShow()

## Set app-specific environment variable for the PAD
epicsEnvSet ("EPICS_CA_MAX_ARRAY_BYTES", "600000")

## Register all support components
dbLoadDatabase("dbd/pad.dbd")
pad_registerRecordDeviceDriver(pdbbase) 

## Load record instances
dbLoadTemplate("db/padBPH.bph_template")
dbLoadRecords("db/iocAdmin.db","IOC=EIOC:IN20:RD13")

## Set to 2 so that we see errors
devLongoutPadFlag=2
devLonginPadFlag=2
devWaveformPadFlag=2
devMbboPadFlag=2
devBoPadFlag=2
drvPadFlag=2
drvPadCfgFlag=4
drvPadScalFlag=2
drvPadIntrFlag=2

iocInit()

drvPadScalFlag=2

# New: pre maps /data to /u1/lcls/epics/ioc/data/<hostname>
dbRestore("/data/EIOC-IN20-RD13.sav")

# force scalar waveforms to read (once)
dbpf("PCAV:IN20:365:PH1_0_SCL_WF.PROC","1")
dbpf("PCAV:IN20:365:PH1_1_SCL_WF.PROC","1")
dbpf("PCAV:IN20:365:PH1_2_SCL_WF.PROC","1")
dbpf("PCAV:IN20:365:PH1_3_SCL_WF.PROC","1")

# if testing by hand, stop some stuff from processing
#dbpf("PCAV:IN20:365:PH1_SLOWADC0.SCAN", "Passive")
#dbpf("PCAV:IN20:365:PH1_SLOWADC1.SCAN", "Passive")
#dbpf("PCAV:IN20:365:PH1_SLOWADC2.SCAN", "Passive")
#dbpf("PCAV:IN20:365:PH1_SLOWADC3.SCAN", "Passive")
#dbpf("PCAV:IN20:365:PH1_SLOWADC4.SCAN", "Passive")
#dbpf("PCAV:IN20:365:PH1_SLOWADC5.SCAN", "Passive")
#dbpf("PCAV:IN20:365:PH1_SLOWADC6.SCAN", "Passive")
#dbpf("PCAV:IN20:365:PH1_SLOWADC7.SCAN", "Passive")

#override what's set for the offset to the start of the data here
#padSetSampleOffset(channel, sample, n) usage: sample is the sample number (0 for most, can be 1 if BPH)
#                                     n is the number of 16 bit words to read 
#                                     after first 3 clock cycless. 
dbpf("PCAV:IN20:365:PH1_0_OF_0.PROC","1")
dbpf("PCAV:IN20:365:PH1_1_OF_0.PROC","1")
dbpf("PCAV:IN20:365:PH1_2_OF_0.PROC","1")
dbpf("PCAV:IN20:365:PH1_3_OF_0.PROC","1")
dbpf("PCAV:IN20:365:PH1_0_OF_1.PROC","1")
dbpf("PCAV:IN20:365:PH1_1_OF_1.PROC","1")
dbpf("PCAV:IN20:365:PH1_2_OF_1.PROC","1")
dbpf("PCAV:IN20:365:PH1_3_OF_1.PROC","1")
dbpf("PCAV:IN20:365:PH1_4_OFST","0")
dbpf("PCAV:IN20:365:PH1_5_OFST","0")
dbpf("PCAV:IN20:365:PH1_6_OFST","0")
dbpf("PCAV:IN20:365:PH1_7_OFST","0")

#override what's set for the size of the data here
#padSetSampleSize(channel, sample, n) usage: sample is the sample number (0 for most, can be 1 if BPH)
#                                   n must be a multiple of 4 since 
#                                   data in quadruples of (Q1,I2,Q3,I4) read 
#                                   (see comments in drvPad.c for more info)
dbpf("PCAV:IN20:365:PH1_0_SZ_0.PROC","1")
dbpf("PCAV:IN20:365:PH1_1_SZ_0.PROC","1")
dbpf("PCAV:IN20:365:PH1_2_SZ_0.PROC","1")
dbpf("PCAV:IN20:365:PH1_3_SZ_0.PROC","1")
dbpf("PCAV:IN20:365:PH1_0_SZ_1.PROC","1")
dbpf("PCAV:IN20:365:PH1_1_SZ_1.PROC","1")
dbpf("PCAV:IN20:365:PH1_2_SZ_1.PROC","1")
dbpf("PCAV:IN20:365:PH1_3_SZ_1.PROC","1")
dbpf("PCAV:IN20:365:PH1_4_SIZE","65536")
dbpf("PCAV:IN20:365:PH1_5_SIZE","65536")
dbpf("PCAV:IN20:365:PH1_6_SIZE","65536")
dbpf("PCAV:IN20:365:PH1_7_SIZE","65536")

padSetDataFileStem("dayle") 	# The stem to start all data files with
                                # Format is "<stem><secPastEpoch>.dat"

# change directory to local mountpoint so that files don't need path to dir in their name
cd("/data") # for lcls-dev
#cd("/mntPt") # for klyron

#rtems_gdb_start(0,0)

## Start any sequence programs. Note: RTEMS Cexp syntax
# Skip state machine for nonlin test
seq(&sncpad,"PRIM=PCAV,LOCA=IN20,UNIT=365,PAD=PH1") 
