## PAD RTEMS startup script for Reference PAD in RF Hut PAD_REF app

chdir("/boot/lcls/epics/iocTop/LLRF/Pad-Prod")
ld("bin/RTEMS-uC5282/pad-ref.obj")

## Set common environment variables
< /boot/lcls/epics/iocCommon/All/Prod/pre_st.cmd

## /data now mapped by pre...
nfsMountsShow()

## Register all support components
dbLoadDatabase("dbd/pad.dbd")
pad_registerRecordDeviceDriver(pdbbase) 

## Load record instances
dbLoadTemplate("db/padREF.ref_template")
dbLoadRecords("db/iocAdmin.db","IOC=EIOC:IN20:RD01")

## Set to 2 so that we see errors
devLongoutPadFlag=2
devLonginPadFlag=2
devWaveformPadFlag=2
devMbboPadFlag=2
devBoPadFlag=2
drvPadFlag=2
drvPadCfgFlag=4
drvPadScalFlag=2
drvPadIntrFlag=2
drvPadGenFlag=2
drvPadIfqFlag=2
drvPadRefFlag=2
drvPadBphFlag=2
drvPadSimpFlag=2

# New: pre maps /data to /u1/lcls/epics/ioc/data/<hostname>
dbRestore("/data/EIOC-IN20-RD01.sav")

iocInit()

# lower flags from 4 to 2 if too verbose for processing
devWaveformPadFlag=2

# force scalar waveforms to read (once)
dbpf("LLRF:IN20:RH:REF_0_SCL_WF.PROC","1")
dbpf("LLRF:IN20:RH:REF_1_SCL_WF.PROC","1")
dbpf("LLRF:IN20:RH:REF_2_SLI_WF.PROC","1")
dbpf("LLRF:IN20:RH:REF_2_SLQ_WF.PROC","1")
dbpf("LLRF:IN20:RH:REF_3_SCL_WF.PROC","1")
# if testing by hand, stop some stuff from processing
#dbpf("LLRF:IN20:RH:REF_0.SCAN", "Passive")
#dbpf("LLRF:IN20:RH:REF_1.SCAN", "Passive")
#dbpf("LLRF:IN20:RH:REF_2.SCAN", "Passive")
#dbpf("LLRF:IN20:RH:REF_3.SCAN", "Passive")
#dbpf("LLRF:IN20:RH:REF_4.SCAN", "Passive")
#dbpf("LLRF:IN20:RH:REF_5.SCAN", "Passive")
#dbpf("LLRF:IN20:RH:REF_6.SCAN", "Passive")
#dbpf("LLRF:IN20:RH:REF_7.SCAN", "Passive")

#override what's set for the offset to the start of the data here
#padSetSampleOffset(channel, sample, n) usage: sample is the sample number (0 for most, can be 1 if BPH)
#                                     n is the number of 16 bit words to read 
#                                     after first 3 clock cycless. 
dbpf("LLRF:IN20:RH:REF_4_OFST","0")
dbpf("LLRF:IN20:RH:REF_5_OFST","0")
dbpf("LLRF:IN20:RH:REF_6_OFST","0")
dbpf("LLRF:IN20:RH:REF_7_OFST","0")

#override what's set for the size of the data here
#padSetSampleSize(channel, sample, n) usage: sample is the sample number (0 for most, can be 1 if BPH)
#                                   n must be a multiple of 4 since 
#                                   data in quadruples of (Q1,I2,Q3,I4) read 
#                                   (see comments in drvPad.c for more info)
dbpf("LLRF:IN20:RH:REF_4_SIZE","65536")
dbpf("LLRF:IN20:RH:REF_5_SIZE","65536")
dbpf("LLRF:IN20:RH:REF_6_SIZE","65536")
dbpf("LLRF:IN20:RH:REF_7_SIZE","65536")

#padSetDataFileStem("dayle") 	# The stem to start all data files with
                                # Format is "<stem><secPastEpoch>.dat"

# change directory to local mountpoint for data
#cd("/data")
#cd("/mntPt") # for klyron

rtems_gdb_start(0,0)

dbpf("LLRF:IN20:RH:REF_0_OFST.PROC","1")
dbpf("LLRF:IN20:RH:REF_1_OFST.PROC","1")
dbpf("LLRF:IN20:RH:REF_2_OFST.PROC","1")
dbpf("LLRF:IN20:RH:REF_3_OFST.PROC","1")
dbpf("LLRF:IN20:RH:REF_0_SIZE.PROC","1")
dbpf("LLRF:IN20:RH:REF_1_SIZE.PROC","1")
dbpf("LLRF:IN20:RH:REF_2_SIZE.PROC","1")
dbpf("LLRF:IN20:RH:REF_3_SIZE.PROC","1")

drvPadCfgFlag=2

## Start any sequence programs. Note: RTEMS Cexp syntax
# Skip state machine for nonlin test
seq(&sncpad,"PRIM=LLRF,LOCA=IN20,UNIT=RH,PAD=REF") 

# for non-lin test
#padSetOperationMode(1)
#padDisableIntr()
#padNonlin(1000)

